# Thanks for the support!

This project is open for contribution to improve the robustness and flexibility in supporting additional components for Project J.A.I.son.

If you have found an issue, please file an issue.
If you want to make changes, please make a pull request from you forked changes. Be descriptive in what you are changing and reference relevant filed issues if any.

I will not be accepting changes that involve breaking changes to the API. If you think the API needs a change, please file an issue or let me know in my [Discord server](https://discord.gg/Z8yyEzHsYM).